@@ -1,10 +1,10 @@
 import logging
 from typing import Any, Dict, List, Tuple
 
-from datayoga_core import expression
+from datayoga_core import expression, utils
 from datayoga_core.block import Block as DyBlock
-from datayoga_core.block import Result
 from datayoga_core.context import Context
+from datayoga_core.result import Result
 
 logger = logging.getLogger("dy")
 
@@ -17,4 +17,5 @@ class Block(DyBlock):
     async def run(self, data: List[Dict[str, Any]]) -> Tuple[List[Dict[str, Any]], List[Result]]:
         logger.debug(f"Running {self.get_block_name()}")
         return_data = self.expression.filter(data)
-        return return_data, [Result.SUCCESS] * len(return_data)
+
+        return utils.all_success(return_data)
